#
# spec file for package newsflash
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         _lto_cflags %{nil}
%define         appname io.gitlab.news_flash.NewsFlash
Name:           newsflash
Version:        3.2.0
Release:        1.1
Summary:        The spiritual successor to FeedReader
License:        GPL-3.0-only
URL:            https://gitlab.com/news-flash/news_flash_gtk
Source0:        news_flash_gtk-%{version}.tar.zst
Source1:        vendor.tar.zst
Patch0:         show-actual-version.patch
BuildRequires:  appstream-glib
BuildRequires:  blueprint-compiler
BuildRequires:  cargo-packaging
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  gettext-tools
BuildRequires:  glib-networking
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-gobject
BuildRequires:  update-desktop-files
BuildRequires:  xdg-utils
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(webkitgtk-6.0)

%description
NewsFlash is a program designed to complement an already existing web-based RSS reader account.
It combines all the advantages of web based services like syncing across all your devices with everything you expect
from a modern desktop program: Desktop notifications, fast search and filtering, tagging, handy keyboard shortcuts
and having access to all your articles as long as you like.

%lang_package

%prep
%autosetup -p1 -a1 -n news_flash_gtk-%{version}

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file %{appname}

%find_lang %{name}

%files
%license LICENSE
%doc README.md
%{_bindir}/io.gitlab.news_flash.NewsFlash
%{_datadir}/applications/%{appname}.desktop
%{_iconsdir}/hicolor/scalable/apps/%{appname}.svg
%{_iconsdir}/hicolor/symbolic/apps/%{appname}-symbolic.svg
%{_datadir}/metainfo/%{appname}.appdata.xml

%files lang -f %{name}.lang

%changelog
* Fri May 10 2024 Richard Rahl <rrahl0@disroot.org>
- update to 3.2.0:
  * new per feed setting: scrap articles
  * local RSS: edit feed url
  * option to manually clean database
  * article list performance improvements
  * use adwaita adaptive dialogs
- show actual version in the app (show-actual-version.patch)
- improve on the spec file
- temporarily disable dep updating, as it breaks compile
* Wed Mar  6 2024 Richard Rahl <rrahl0@proton.me>
- update to 3.1.6:
  * fix shortcuts blocking text input
  * fix zooming articles with ctrl + touch pad scroll
* Fri Mar  1 2024 Richard Rahl <rrahl0@proton.me>
- update to 3.1.5:
  * activate running instance window when clicking launcher
- update to 3.1.4:
  * add cli option to subscribe to feed
  * open article in browser via mouse wheel click and 3 finger press
  * clear article list on mark all read
  * add shortcut to close an article
  * fix url overlay positioning
  * keep track of subscriptions and tags expansion state
  * fix mark all as read spinner
  * show shortcuts in menus
* Fri Feb 16 2024 Richard Rahl <rrahl0@proton.me>
- update to 3.1.3:
  * fix appdata screenshots
- update to 3.1.2:
  * revert user agent change of 3.1.0
  * fix mark all as read when closing the app right afterwards
  * add share to clipboard
  * stop using trust DNS
  * limit concurrent HTTP calls to avoid DNS issues
  * FreshRSS: automatically add missing slash to Url on login
  * article scraper: add null checks in hope to prevent crashes
* Mon Feb 12 2024 Richard Rahl <rrahl0@proton.me>
- update to 3.1.1:
  * fix pushing read updates to the API
* Mon Feb 12 2024 Richard Rahl <rrahl0@proton.me>
- update to 3.1.0:
  * Fix tag context menu actions
  * Fix article scrolling on steam deck
  * Fix an error toast appearing right after successful login
  * Fix multiple instances of the image dialog spawning at the same time
  * Fix 12h/24h time format
  * Fix webview scrolling when zoomed via touch
  * Local RSS: Fix duplicate feeds after exporting and reimporting an OPML file
  * miniflux: support article enclosures
  * Mark articles as read when opening in external browser
  * Keep loaded articles when refreshing unread article list
  * Update the user agent
  * Add 'Zorin' article theme
  * Double check if Newsflash is offline by pinging an Url
  * Mark all read: only apply to articles that match current search term and list mode
  * Article View: remove selectabilty preference and make content selectable by default
  * Fetch content of a feed after adding it (if backend supports it)
  * Show fetch and parse issues of single feeds (if backend supports it)
  * Allow undoing mark all as read
* Fri Dec  8 2023 Richard Rahl <rrahl0@proton.me>
- initial packaging for openSUSE_Tumbleweed
